#' @name atom4R
#' @aliases atom4R-package
#' @aliases atom4R
#'
#' @import R6
#' @import methods
#' @import jsonlite
#' @import XML
#' @import httr
#' @importFrom zip zipr
#' @import rdflib
#' @import keyring
#'
#' @title  Tools to Handle and Publish Metadata as Atom XML Format
#' @description Provides tools to read/write/publish metadata based on the Atom XML syndication format.
#' This includes support of Dublin Core XML implementation, and a client to APIs implementing the AtomPub
#' SWORD API specification.
#'
#'@author Emmanuel Blondel \email{emmanuel.blondel1@@gmail.com}
#'
"_PACKAGE"
